@@ -1,8 +1,5 @@
-import time
-
 import pytest
 
-from funcx.sdk.client import FuncXClient
 from funcx.utils.response_errors import FunctionNotFound
 
 
