@@ -2,8 +2,6 @@ import time
 
 import pytest
 
-from funcx.sdk.client import FuncXClient
-
 
 def double(x):
     return x * 2
@@ -29,7 +27,7 @@ def test_performance(fxc, endpoint, task_count):
     for _i in range(10):
         x = fxc.get_batch_result(task_ids)
         complete_count = sum(
-            [1 for t in task_ids if t in x and not x[t].get("pending", False)]
+            1 for t in task_ids if t in x and not x[t].get("pending", False)
         )
         print(f"Batch status : {complete_count}/{len(task_ids)} complete")
         if complete_count == len(task_ids):
