@@ -1,10 +1,6 @@
-import argparse
-import time
-
 import pytest
 
-from funcx.sdk.client import FuncXClient
-from funcx_endpoint.executors.high_throughput.funcx_worker import MaxResultSizeExceeded
+from funcx.utils.errors import MaxResultSizeExceeded, TaskPending
 
 
 def large_result_producer(size) -> str:
@@ -20,14 +16,39 @@ def wait_for_task(fxc, task_id, walltime: int = 2):
             raise Exception("Timeout")
         try:
             r = fxc.get_result(task_id)
-        except Exception:
+        except TaskPending:
             print("Not available yet")
             time.sleep(1)
+        except Exception as e:
+            raise e
         else:
             return r
 
 
-def test_large_result(fxc, endpoint, size=(11 * (2 ** 20))):
+test_cases = [4500, 45000, 35000]
+
+
+@pytest.mark.parametrize("size", test_cases)
+def test_allowed_result_sizes(fxc, endpoint, size):
+    """funcX should allow all listed result sizes which are under 512KB limit"""
+    fn_uuid = fxc.register_function(
+        large_result_producer, endpoint, description="LargeResultProducer"
+    )
+    task_id = fxc.run(
+        size,  # This is the current result size limit
+        endpoint_id=endpoint,
+        function_id=fn_uuid,
+    )
+
+    x = wait_for_task(fxc, task_id, walltime=10)
+    assert len(x) == size, "Result size does not match excepted size"
+
+
+def test_result_size_too_large(fxc, endpoint, size=11 * 1024 * 1024):
+    """
+    funcX should raise a MaxResultSizeExceeded exception when results exceeds 10MB
+    limit
+    """
     fn_uuid = fxc.register_function(
         large_result_producer, endpoint, description="LargeResultProducer"
     )
@@ -37,20 +58,5 @@ def test_large_result(fxc, endpoint, size=(11 * (2 ** 20))):
         function_id=fn_uuid,
     )
 
-    print("Task_id: ", task_id)
-    # Replace the stupid sleep
-    time.sleep(5)
     with pytest.raises(MaxResultSizeExceeded):
-        fxc.get_result(task_id)
-
-
-if __name__ == "__main__":
-
-    parser = argparse.ArgumentParser()
-    parser.add_argument("-e", "--endpoint_id", required=True)
-    args = parser.parse_args()
-
-    fxc = FuncXClient()
-    endpoint = args.endpoint_id
-    test_large_result(fxc, endpoint, 2 ** 10)
-    test_large_result(fxc, endpoint, 11 * (2 ** 20))  # 11 MB exceeds the limit
+        wait_for_task(fxc, task_id, walltime=10)
